@@ -105,18 +105,18 @@ static bool SetupAPTPartialDirectory(std::string const &grand, std::string const
 	 {
 	    // chown the partial dir
 	    if(chown(partial.c_str(), pw->pw_uid, gr->gr_gid) != 0)
-	       _error->WarningE("SetupAPTPartialDirectory", "chown to %s:root of directory %s failed", SandboxUser.c_str(), partial.c_str());
+	       _error->WarningE("SetupAPTPartialDirectory", "chown to %s:%s of directory %s failed", SandboxUser.c_str(), ROOT_GROUP, partial.c_str());
 	 }
       }
       if (chmod(partial.c_str(), mode) != 0)
-	 _error->WarningE("SetupAPTPartialDirectory", "chmod 0700 of directory %s failed", partial.c_str());
+	 _error->WarningE("SetupAPTPartialDirectory", "chmod 0%03o of directory %s failed", mode, partial.c_str());
 
    }
    else if (chmod(partial.c_str(), mode) != 0)
    {
       // if we haven't created the dir and aren't root, it is kinda expected that chmod doesn't work
       if (partialExists == false)
-	 _error->WarningE("SetupAPTPartialDirectory", "chmod 0700 of directory %s failed", partial.c_str());
+	 _error->WarningE("SetupAPTPartialDirectory", "chmod 0%03o of directory %s failed", mode, partial.c_str());
    }
 
    _error->PushToStack();
@@ -780,7 +780,6 @@ pkgAcquire::Worker *pkgAcquire::WorkerStep(Worker *I)
 // ---------------------------------------------------------------------
 /* This is a bit simplistic, it looks at every file in the dir and sees
    if it is part of the download set. */
-__attribute__((optimize("no-optimize-strlen"))) // strcmp() below reads too much
 bool pkgAcquire::Clean(string Dir)
 {
    // non-existing directories are by definition clean…
@@ -1475,5 +1474,5 @@ pkgAcquire::UriIterator::UriIterator(pkgAcquire::Queue *Q) : d(NULL), CurQ(Q), C
 }
 
 pkgAcquire::UriIterator::~UriIterator() {}
-pkgAcquire::MethodConfig::~MethodConfig() {}
+pkgAcquire::MethodConfig::~MethodConfig() { delete d; }
 pkgAcquireStatus::~pkgAcquireStatus() {}
