@@ -55,17 +55,7 @@ struct ExtractTar::TarHeader
    char Major[8];
    char Minor[8];      
 };
-
-// We need to read long names (names and link targets) into memory, so let's
-// have a limit (shamelessly stolen from libarchive) to avoid people OOMing
-// us with large streams.
-static const unsigned long long APT_LONGNAME_LIMIT = 1048576llu;
-
-// A file size limit that we allow extracting. Currently, that's 128 GB.
-// We also should leave some wiggle room for code adding files to it, and
-// possibly conversion for signed, so this should not be larger than like 2**62.
-static const unsigned long long APT_FILESIZE_LIMIT = 1llu << 37;
-
+   
 // ExtractTar::ExtractTar - Constructor					/*{{{*/
 // ---------------------------------------------------------------------
 /* */
@@ -176,11 +166,6 @@ bool ExtractTar::Go(pkgDirStream &Stream)
 	  StrToNum(Tar->Minor,Itm.Minor,sizeof(Tar->Minor),8) == false)
 	 return _error->Error(_("Corrupted archive"));
 
-      // Security check. Prevents overflows below the code when rounding up in skip/copy code,
-      // and provides modest protection against decompression bombs.
-      if (Itm.Size > APT_FILESIZE_LIMIT)
-	 return _error->Error("Tar member too large: %llu > %llu bytes", Itm.Size, APT_FILESIZE_LIMIT);
-
       // Grab the filename and link target: use last long name if one was
       // set, otherwise use the header value as-is, but remember that it may
       // fill the entire 100-byte block and needs to be zero-terminated.
@@ -233,8 +218,6 @@ bool ExtractTar::Go(pkgDirStream &Stream)
 	 {
 	    unsigned long long Length = Itm.Size;
 	    unsigned char Block[512];
-	    if (Length > APT_LONGNAME_LIMIT)
-	       return _error->Error("Long name to large: %llu bytes > %llu bytes", Length, APT_LONGNAME_LIMIT);
 	    while (Length > 0)
 	    {
 	       if (InFd.Read(Block,sizeof(Block),true) == false)
@@ -254,8 +237,6 @@ bool ExtractTar::Go(pkgDirStream &Stream)
 	 {
 	    unsigned long long Length = Itm.Size;
 	    unsigned char Block[512];
-	    if (Length > APT_LONGNAME_LIMIT)
-	       return _error->Error("Long name to large: %llu bytes > %llu bytes", Length, APT_LONGNAME_LIMIT);
 	    while (Length > 0)
 	    {
 	       if (InFd.Read(Block,sizeof(Block),true) == false)
@@ -276,50 +257,50 @@ bool ExtractTar::Go(pkgDirStream &Stream)
 	 _error->Warning(_("Unknown TAR header type %u"), (unsigned)Tar->LinkFlag);
 	 break;
       }
-      
+
       int Fd = -1;
-      if (BadRecord == false)
-	 if (Stream.DoItem(Itm,Fd) == false)
-	    return false;
-      
-      // Copy the file over the FD
-      unsigned long long Size = Itm.Size;
-      while (Size != 0)
+      if (not BadRecord && not Stream.DoItem(Itm, Fd))
+	 return false;
+
+      if (Fd == -1 || Fd < -2 || BadRecord)
       {
-	 unsigned char Junk[32*1024];
-	 unsigned long Read = min(Size, (unsigned long long)sizeof(Junk));
-	 if (InFd.Read(Junk,((Read+511)/512)*512) == false)
+	 if (Itm.Size > 0 && not InFd.Skip(((Itm.Size + (sizeof(Block) - 1)) / sizeof(Block)) * sizeof(Block)))
 	    return false;
-	 
-	 if (BadRecord == false)
+      }
+      else if (Itm.Size != 0)
+      {
+	 // Copy the file over the FD
+	 auto Size = Itm.Size;
+	 unsigned char Junk[32*1024];
+	 do
 	 {
+	    auto const Read = std::min<unsigned long long>(Size, sizeof(Junk));
+	    if (not InFd.Read(Junk, ((Read + (sizeof(Block) - 1)) / sizeof(Block)) * sizeof(Block)))
+	       return false;
+
 	    if (Fd > 0)
 	    {
-	       if (write(Fd,Junk,Read) != (signed)Read)
-		  return Stream.Fail(Itm,Fd);
+	       if (not FileFd::Write(Fd, Junk, Read))
+		  return Stream.Fail(Itm, Fd);
 	    }
-	    else
+	    // An Fd of -2 means to send to a special processing function
+	    else if (Fd == -2)
 	    {
-	       /* An Fd of -2 means to send to a special processing
-		  function */
-	       if (Fd == -2)
-		  if (Stream.Process(Itm,Junk,Read,Itm.Size - Size) == false)
-		     return Stream.Fail(Itm,Fd);
+	       if (not Stream.Process(Itm, Junk, Read, Itm.Size - Size))
+		  return Stream.Fail(Itm, Fd);
 	    }
-	 }
-	 
-	 Size -= Read;
+
+	    Size -= Read;
+	 } while (Size != 0);
       }
-      
+
       // And finish up
-      if (BadRecord == false)
-	 if (Stream.FinishedFile(Itm,Fd) == false)
-	    return false;
-      
+      if (not BadRecord && not Stream.FinishedFile(Itm, Fd))
+	 return false;
       LastLongName.erase();
       LastLongLink.erase();
    }
-   
+
    return Done();
 }
 									/*}}}*/
